@@ -7,7 +7,7 @@ sparse = pytest.importorskip("scipy.sparse")
 
 import networkx as nx
 from networkx.algorithms import bipartite
-from networkx.testing.utils import assert_edges_equal
+from networkx.utils import edges_equal
 
 
 class TestBiadjacencyMatrix:
@@ -39,6 +39,11 @@ class TestBiadjacencyMatrix:
         M = bipartite.biadjacency_matrix(G, X, Y, weight="weight")
         assert M[1, 2] == 2
 
+    def test_biadjacency_matrix_empty_graph(self):
+        G = nx.empty_graph(2)
+        M = nx.bipartite.biadjacency_matrix(G, [0])
+        assert np.array_equal(M.toarray(), np.array([[0]]))
+
     def test_null_graph(self):
         with pytest.raises(nx.NetworkXError):
             bipartite.biadjacency_matrix(nx.Graph(), [])
@@ -68,12 +73,12 @@ class TestBiadjacencyMatrix:
     def test_from_biadjacency_weight(self):
         M = sparse.csc_matrix([[1, 2], [0, 3]])
         B = bipartite.from_biadjacency_matrix(M)
-        assert_edges_equal(B.edges(), [(0, 2), (0, 3), (1, 3)])
+        assert edges_equal(B.edges(), [(0, 2), (0, 3), (1, 3)])
         B = bipartite.from_biadjacency_matrix(M, edge_attribute="weight")
         e = [(0, 2, {"weight": 1}), (0, 3, {"weight": 2}), (1, 3, {"weight": 3})]
-        assert_edges_equal(B.edges(data=True), e)
+        assert edges_equal(B.edges(data=True), e)
 
     def test_from_biadjacency_multigraph(self):
         M = sparse.csc_matrix([[1, 2], [0, 3]])
         B = bipartite.from_biadjacency_matrix(M, create_using=nx.MultiGraph())
-        assert_edges_equal(B.edges(), [(0, 2), (0, 3), (0, 3), (1, 3), (1, 3), (1, 3)])
+        assert edges_equal(B.edges(), [(0, 2), (0, 3), (0, 3), (1, 3), (1, 3), (1, 3)])
