@@ -21,6 +21,7 @@ __all__ = [
 # TODO STILL NEED TO UPDATE ALL THE DOCUMENTATION!
 
 
+@nx._dispatchable(edge_attrs="weight")
 def cut_size(G, S, T=None, weight=None):
     """Returns the size of the cut between two sets of nodes.
 
@@ -32,11 +33,11 @@ def cut_size(G, S, T=None, weight=None):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
-    T : sequence
-        A sequence of nodes in `G`. If not specified, this is taken to
+    T : collection
+        A collection of nodes in `G`. If not specified, this is taken to
         be the set complement of `S`.
 
     weight : object
@@ -83,6 +84,7 @@ def cut_size(G, S, T=None, weight=None):
     return sum(weight for u, v, weight in edges)
 
 
+@nx._dispatchable(edge_attrs="weight")
 def volume(G, S, weight=None):
     """Returns the volume of a set of nodes.
 
@@ -93,8 +95,8 @@ def volume(G, S, weight=None):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
     weight : object
         Edge attribute key to use as weight. If not specified, edges
@@ -125,6 +127,7 @@ def volume(G, S, weight=None):
     return sum(d for v, d in degree(S, weight=weight))
 
 
+@nx._dispatchable(edge_attrs="weight")
 def normalized_cut_size(G, S, T=None, weight=None):
     """Returns the normalized size of the cut between two sets of nodes.
 
@@ -135,11 +138,11 @@ def normalized_cut_size(G, S, T=None, weight=None):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
-    T : sequence
-        A sequence of nodes in `G`.
+    T : collection
+        A collection of nodes in `G`.
 
     weight : object
         Edge attribute key to use as weight. If not specified, edges
@@ -177,6 +180,7 @@ def normalized_cut_size(G, S, T=None, weight=None):
     return num_cut_edges * ((1 / volume_S) + (1 / volume_T))
 
 
+@nx._dispatchable(edge_attrs="weight")
 def conductance(G, S, T=None, weight=None):
     """Returns the conductance of two sets of nodes.
 
@@ -187,11 +191,11 @@ def conductance(G, S, T=None, weight=None):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
-    T : sequence
-        A sequence of nodes in `G`.
+    T : collection
+        A collection of nodes in `G`.
 
     weight : object
         Edge attribute key to use as weight. If not specified, edges
@@ -224,6 +228,7 @@ def conductance(G, S, T=None, weight=None):
     return num_cut_edges / min(volume_S, volume_T)
 
 
+@nx._dispatchable(edge_attrs="weight")
 def edge_expansion(G, S, T=None, weight=None):
     """Returns the edge expansion between two node sets.
 
@@ -234,11 +239,11 @@ def edge_expansion(G, S, T=None, weight=None):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
-    T : sequence
-        A sequence of nodes in `G`.
+    T : collection
+        A collection of nodes in `G`.
 
     weight : object
         Edge attribute key to use as weight. If not specified, edges
@@ -270,6 +275,7 @@ def edge_expansion(G, S, T=None, weight=None):
     return num_cut_edges / min(len(S), len(T))
 
 
+@nx._dispatchable(edge_attrs="weight")
 def mixing_expansion(G, S, T=None, weight=None):
     """Returns the mixing expansion between two node sets.
 
@@ -280,11 +286,11 @@ def mixing_expansion(G, S, T=None, weight=None):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
-    T : sequence
-        A sequence of nodes in `G`.
+    T : collection
+        A collection of nodes in `G`.
 
     weight : object
         Edge attribute key to use as weight. If not specified, edges
@@ -317,6 +323,7 @@ def mixing_expansion(G, S, T=None, weight=None):
 
 # TODO What is the generalization to two arguments, S and T? Does the
 # denominator become `min(len(S), len(T))`?
+@nx._dispatchable
 def node_expansion(G, S):
     """Returns the node expansion of the set `S`.
 
@@ -327,8 +334,8 @@ def node_expansion(G, S):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
     Returns
     -------
@@ -356,6 +363,7 @@ def node_expansion(G, S):
 
 # TODO What is the generalization to two arguments, S and T? Does the
 # denominator become `min(len(S), len(T))`?
+@nx._dispatchable
 def boundary_expansion(G, S):
     """Returns the boundary expansion of the set `S`.
 
@@ -366,8 +374,8 @@ def boundary_expansion(G, S):
     ----------
     G : NetworkX graph
 
-    S : sequence
-        A sequence of nodes in `G`.
+    S : collection
+        A collection of nodes in `G`.
 
     Returns
     -------
