@@ -7,6 +7,7 @@ from networkx.utils import arbitrary_element
 __all__ = ["dominating_set", "is_dominating_set"]
 
 
+@nx._dispatchable
 def dominating_set(G, start_with=None):
     r"""Finds a dominating set for the graph G.
 
@@ -54,16 +55,17 @@ def dominating_set(G, start_with=None):
     while remaining_nodes:
         # Choose an arbitrary node and determine its undominated neighbors.
         v = remaining_nodes.pop()
-        undominated_neighbors = set(G[v]) - dominating_set
+        undominated_nbrs = set(G[v]) - dominating_set
         # Add the node to the dominating set and the neighbors to the
         # dominated set. Finally, remove all of those nodes from the set
         # of remaining nodes.
         dominating_set.add(v)
-        dominated_nodes |= undominated_neighbors
-        remaining_nodes -= undominated_neighbors
+        dominated_nodes |= undominated_nbrs
+        remaining_nodes -= undominated_nbrs
     return dominating_set
 
 
+@nx._dispatchable
 def is_dominating_set(G, nbunch):
     """Checks if `nbunch` is a dominating set for `G`.
 
